@@ -119,11 +119,11 @@ def main():
     thr = args.smoothing_threshold
     # match +-10% size random in the pool
     # iterate on sizes from the list in master.sh
-    # roi_size_list = ['300000', '200000', '120000', '110000', '100000', '90000', '80000', '70000', '60000', '50000',
-    #                  '40000', '30000', '20000', '10000', '9000', '8000', '7000', '6000', '5000', '4000', '3000', '2000',
-    #                  '1000', '900', '800', '700', '600', '500', '400', '300', '200', '100', '35000', '25000', '15000']
+    roi_size_list = ['300000', '200000', '120000', '110000', '100000', '90000', '80000', '70000', '60000', '50000',
+                     '40000', '30000', '20000', '10000', '9000', '8000', '7000', '6000', '5000', '4000', '3000', '2000',
+                     '1000', '900', '800', '700', '600', '500', '400', '300', '200', '100', '35000', '25000', '15000']
     # just for testing
-    roi_size_list = ['3000', '4000', '5000']
+    # roi_size_list = ['3000', '4000', '5000']
     # roi_size_list = [6998, 4275, 2300, 11945, 96, 5322, 5604, 8229, 6334, 3765, 8225, 449, 10305, 1755, 753, 2378,
     #                  2834, 4726, 24041,10119, 8366, 24358, 5175, 8380, 2592, 3298, 3946, 11453, 7328, 3073, 5104,
     #                  1065, 2532, 4849, 5930, 27200, 304]
